@@ -1,4 +1,7 @@
 package EWS::Calendar::Item;
+BEGIN {
+  $EWS::Calendar::Item::VERSION = '1.130540_001';
+}
 use Moose;
 
 use Moose::Util::TypeConstraints;
@@ -75,7 +78,7 @@ sub has_Location { return length ((shift)->Location) }
 
 has CalendarItemType => (
     is => 'ro',
-    isa => enum([qw/Single Occurrence Eception/]),
+    isa => enum([qw/Single Occurrence Exception/]),
     required => 1,
 );
 
