@@ -1,4 +1,7 @@
 package EWS::Calendar::Role::RetrieveWithinWindow;
+BEGIN {
+  $EWS::Calendar::Role::RetrieveWithinWindow::VERSION = '1.130540_001';
+}
 use Moose::Role;
 
 use EWS::Calendar::ResultSet;
@@ -34,9 +37,19 @@ sub _list_calendaritems {
 # Find list of items within the view, then Get details for each one
 # (item:Body is only available this way, it's not returned by FindItem)
 sub retrieve_within_window {
-    my ($self, $query) = @_;
+    my ($self, $opts) = @_;
 
     my $find_response = scalar $self->client->FindItem->(
+        (exists $opts->{impersonate} ? (
+            Impersonation => {
+                ConnectingSID => {
+                    PrimarySmtpAddress => $opts->{impersonate},
+                }
+            },
+        ) : ()),
+        RequestVersion => {
+            Version => $self->client->server_version,
+        },
         Traversal => 'Shallow',
         ItemShape => {
             BaseShape => 'IdOnly',
@@ -51,8 +64,8 @@ sub retrieve_within_window {
             ],
         },
         CalendarView => {
-            StartDate => $query->start->iso8601,
-            EndDate   => $query->end->iso8601,
+            StartDate => $opts->{window}->start->iso8601,
+            EndDate   => $opts->{window}->end->iso8601,
         },
     );
 
@@ -65,6 +78,16 @@ sub retrieve_within_window {
         if scalar @ids == 0;
 
     my $get_response = scalar $self->client->GetItem->(
+        (exists $opts->{impersonate} ? (
+            Impersonation => {
+                ConnectingSID => {
+                    PrimarySmtpAddress => $opts->{impersonate},
+                }
+            },
+        ) : ()),
+        RequestVersion => {
+            Version => $self->client->server_version,
+        },
         ItemShape => {
             BaseShape => 'IdOnly',
             AdditionalProperties => {
