@@ -1,4 +1,7 @@
 package EWS::Client;
+BEGIN {
+  $EWS::Client::VERSION = '1.130540_001';
+}
 use Moose;
 
 with qw/
@@ -10,17 +13,14 @@ use EWS::Client::Contacts;
 use EWS::Client::Calendar;
 use URI::Escape ();
 
-our $VERSION = '0.06';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 has username => (
-    is => 'ro',
+    is => 'rw',
     isa => 'Str',
     required => 1,
 );
 
 has password => (
-    is => 'ro',
+    is => 'rw',
     isa => 'Str',
     required => 1,
 );
@@ -60,19 +60,39 @@ sub BUILDARGS {
     # collect EWS password from environment as last resort
     $params->{password} ||= $ENV{EWS_PASS};
 
-    # URI escape the username and password
-    $params->{username} ||= '';
-    $params->{username} = URI::Escape::uri_escape($params->{username});
-    $params->{password} = URI::Escape::uri_escape($params->{password});
-
     return $params;
 }
 
+sub BUILD {
+    my ($self, $params) = @_;
+
+    if ($self->use_negotiated_auth) {
+        die "please install LWP::Authen::Ntlm"
+            unless eval { require LWP::Authen::Ntlm && $LWP::Authen::Ntlm::VERSION };
+        die "please install Authen::NTLM"
+            unless eval { require Authen::NTLM && $Authen::NTLM::VERSION };
+
+        # change email style username to win-domain style
+        if ($self->username =~ m/(.+)@(.+)/) {
+            $self->username( $2 .'\\'. $1 );
+        }
+    }
+    else {
+        # URI escape the username and password
+        $self->password( URI::Escape::uri_escape($self->password) );
+        $self->username( URI::Escape::uri_escape($self->username) );
+    }
+}
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
+# ABSTRACT: Microsoft Exchange Web Services Client
+
+
 __END__
+=pod
 
 =head1 NAME
 
@@ -80,12 +100,11 @@ EWS::Client - Microsoft Exchange Web Services Client
 
 =head1 VERSION
 
-This document refers to version 0.06 of EWS::Client
+version 1.130540_001
 
 =head1 SYNOPSIS
 
-Set up your Exchange Web Services client. I<You will need HTTP Basic Access
-Auth enabled on the Exchange server to use this module>:
+Set up your Exchange Web Services client.
 
  use EWS::Client;
  use DateTime;
@@ -100,7 +119,7 @@ Then perform operations on the Exchange server:
 
  my $entries = $ews->calendar->retrieve({
      start => DateTime->now(),
-     end   => DateTime->now->add( month => 1 ),
+     end   => DateTime->now->add( months => 1 ),
  });
  
  print "I retrieved ". $entries->count ." items\n";
@@ -118,13 +137,21 @@ here you can access calendar and contact entries in a nicely abstracted
 fashion. Query results are generally available in an iterator and convenience
 methods exist to access the properties of each entry.
 
+=head1 AUTHENTICATION
+
+Depending on the configuration of the Microsoft Exchange server, you can use
+either HTTP Basic Access Auth, or NTLM Negotiated Auth, from this module. The
+default is HTTP Basic Access Auth, so if using NTLM, the following additional
+option to C<new()> is required:
+
+ use_negotiated_auth => 1,
+
 =head1 METHODS
 
 =head2 EWS::Client->new( \%arguments )
 
 Instantiates a new EWS client. There won't be any connection to the server
-until you call one of the calendar or contacts retrieval methods. You will
-need HTTP Basic Access Auth enabled on the Exchange server to use this module.
+until you call one of the calendar or contacts retrieval methods.
 
 =over 4
 
@@ -134,14 +161,25 @@ The host name of the Exchange server to which the module should connect.
 
 =item C<username> => String (required)
 
-The account username under which the module will connect to Exchange. This
-value will be URI encoded by the module.
+The account username under which the module will connect to Exchange.
+
+For Basic Access Auth this value will be URI encoded by the module, meaning
+you don't have to worry about escaping any special characters. For NTLM
+Negotiated Auth, pass a C<user@domain> format username and it will
+automatically be converted into Windows' C<domain\user> format for you.
 
 =item C<password> => String OR via C<$ENV{EWS_PASS}> (required)
 
 The password of the account under which the module will connect to Exchange.
-This value will be URI encoded by the module. You can also provide the
-password via the C<EWS_PASS> environment variable.
+
+For Basic Access Auth this value will be URI encoded by the module. You can
+also provide the password via the C<EWS_PASS> environment variable.
+
+=item C<use_negotiated_auth> => True or False value
+
+The module will assume you wish to use HTTP Basic Access Auth, in which case
+you should enable that in your Exchange server. However for negotiated methods
+such as NTLM set this to a True value.
 
 =item C<schema_path> => String (optional)
 
@@ -149,6 +187,12 @@ A folder on your file system which contains the WSDL and two further Schema
 files (messages, and types) which describe the Exchange 2007 Web Services SOAP
 API. They are shipped with this module so your providing this is optional.
 
+=item C<server_version> => String (optional)
+
+In each request to the server is specified the API version we expect to use.
+By default this is set to C<Exchange2007_SP1> but you have the opportunity to
+set it to C<Exchange2007> if you wish using this option.
+
 =back
 
 =head2 $ews->calendar()
@@ -163,44 +207,31 @@ Retrieves the L<EWS::Client::Contacts> object which allows retrieval of
 contact entries and their telephone numbers. See that linked manual page for
 more details.
 
-=head1 TODO
-
-There is currently no handling of time zone information whatsoever. I'm
-waiting for my timezone to shift to UTC+1 in March before working on this, as
-I don't really want to read the Exchange API docs. Patches are welcome if you
-want to help out.
-
-=head1 REQUIREMENTS
+=head1 KNOWN ISSUES
 
 =over 4
 
-=item * L<Moose>
+=item * No handling of time zone information, sorry.
 
-=item * L<MooseX::Iterator>
-
-=item * L<XML::Compile::SOAP>
-
-=item * L<DateTime>
-
-=item * L<DateTime::Format::ISO8601>
-
-=item * L<HTML::Strip>
-
-=item * L<URI::Escape>
-
-=item * L<File::ShareDir>
+=item * The C<SOAPAction> Header might be wrong for Exchange 2010.
 
 =back
 
+=head1 THANKS
+
+To Greg Shaw for sending patches for NTLM Authentication support and User
+Impersonation.
+
 =head1 AUTHOR
 
-Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
+Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) University of Oxford 2010.
+This software is copyright (c) 2013 by University of Oxford.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
