@@ -1,12 +1,12 @@
 package EWS::Client::Calendar;
+BEGIN {
+  $EWS::Client::Calendar::VERSION = '1.130540_001';
+}
 use Moose;
 
 with 'EWS::Calendar::Role::Reader';
 # could add future roles for updates, here
 
-our $VERSION = '0.01';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 has client => (
     is => 'ro',
     isa => 'EWS::Client',
@@ -18,7 +18,11 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
+# ABSTRACT: Calendar Entries from Microsoft Exchange Server
+
+
 __END__
+=pod
 
 =head1 NAME
 
@@ -26,7 +30,7 @@ EWS::Client::Calendar - Calendar Entries from Microsoft Exchange Server
 
 =head1 VERSION
 
-This document refers to version 0.01 of EWS::Client::Calendar
+version 1.130540_001
 
 =head1 SYNOPSIS
 
@@ -104,6 +108,13 @@ returned results.
 Entries with a start date before this timestamp will be included in the
 results.
 
+=item C<impersonate> => String (optional)
+
+Passing the primary SMTP address of another account will retrieve the entries
+for that Exchange user instead, assuming you have sufficient rights to
+I<Impersonate> that account. If you do not have rights, an error will be
+thrown.
+
 =back
 
 The returned object contains the collection of calendar entries which matched
@@ -322,13 +333,14 @@ want to help out.
 
 =head1 AUTHOR
 
-Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
+Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) University of Oxford 2010.
+This software is copyright (c) 2013 by University of Oxford.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
