@@ -1,12 +1,12 @@
 package EWS::Client::Contacts;
+BEGIN {
+  $EWS::Client::Contacts::VERSION = '1.130540_001';
+}
 use Moose;
 
 with 'EWS::Contacts::Role::Reader';
 # could add future roles for updates, here
 
-our $VERSION = '0.01';
-$VERSION = eval $VERSION; # numify for warning-free dev releases
-
 has client => (
     is => 'ro',
     isa => 'EWS::Client',
@@ -18,7 +18,11 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
+# ABSTRACT: Contact Entries from Microsoft Exchange Server
+
+
 __END__
+=pod
 
 =head1 NAME
 
@@ -26,7 +30,7 @@ EWS::Client::Contacts - Contact Entries from Microsoft Exchange Server
 
 =head1 VERSION
 
-This document refers to version 0.01 of EWS::Client::Contacts
+version 1.130540_001
 
 =head1 SYNOPSIS
 
@@ -83,24 +87,31 @@ reference.
 
 =head2 $contacts->retrieve( \%arguments )
 
-Query the Exchange server and retrieve contact entries. Pass the following
-arguments in a hash ref:
+Query the Exchange server and retrieve contact entries. By default the
+C<retrieve()> method will return contacts for the account under which you
+authenticated to the Exchange server (that is, the credentials passed to the
+L<EWS::Client> constructor). The following arguments will change this
+behaviour:
 
 =over 4
 
 =item C<email> => String (optional)
 
-By default the C<retrieve()> method will return contacts for the account under
-which you authenticated to the Exchange server (that is, the credentials
-passed to the L<EWS::Client> constructor).
-
 Passing the primary SMTP address of another account will retrieve the contacts
-for that Exchange user instead, assuming you have rights to see their
-contacts. If you do not have rights, an error will be thrown.
+for that Exchange user instead using the I<Delegation> feature, assuming you
+have rights to see their contacts (i.e. the user has shared their contacts).
+If you do not have rights, an error will be thrown.
 
 If you pass one of the account's secondary SMTP addresses this module
 I<should> be able to divine the primary SMTP address required.
 
+=item C<impersonate> => String (optional)
+
+Passing the primary SMTP address of another account will retrieve the contacts
+for that Exchange user instead, assuming you have sufficient rights to
+I<Impersonate> that account. If you do not have rights, an error will be
+thrown.
+
 =back
 
 The returned object contains the collection of contact entries and is of type
@@ -160,9 +171,15 @@ types, such as Mobile Phone, Business Line, and so on. Each of these may in
 turn store a free text field so people often put multiple numbers in,
 separated by a delimiter.
 
+As a result of this freedom, this module makes no effort to interpret the
+content of the number fields, only to retrieve them. It's assumed you are
+familiar with your own number storage conventions, or can use a module such
+as L<Number::Phone::Normalize> to parse the result.
+
 In this property you'll find a hash ref of all this data, with keys being the
-number types (Mobile Phone, etc), and values being array refs of numbers. The
-module splits up number lists but preserves their order. For example:
+number types (Mobile Phone, etc), and values being array refs of I<data>. As
+explained above, the data might be single numbers or free text with several
+telephone numbers that you will need to parse yourself. For example:
 
  my $numbers = $entry->PhoneNumbers;
  
@@ -176,19 +193,14 @@ module splits up number lists but preserves their order. For example:
  
  # might print something like:
  
- Oliver Gorwits : 73244
- John Smith : 88888
-
-In the future this format may change, or may migrate into an object based
-storage.
+ Mobile Phone : 73244
+ Business Line : 88888
 
 =head1 TODO
 
 There should be more properties imported than just the DisplayName and
 PhoneNumbers.
 
-PhoneNumbers will maybe migrate into some kind of object based storage.
-
 =head1 SEE ALSO
 
 =over 4
@@ -199,13 +211,14 @@ PhoneNumbers will maybe migrate into some kind of object based storage.
 
 =head1 AUTHOR
 
-Oliver Gorwits C<< <oliver.gorwits@oucs.ox.ac.uk> >>
+Oliver Gorwits <oliver@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) University of Oxford 2010.
+This software is copyright (c) 2013 by University of Oxford.
 
-This library is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
