@@ -1,4 +1,7 @@
 package EWS::Client::Role::SOAP;
+BEGIN {
+  $EWS::Client::Role::SOAP::VERSION = '1.130540_001';
+}
 use Moose::Role;
 
 use XML::Compile::WSDL11;
@@ -6,6 +9,20 @@ use XML::Compile::SOAP11;
 use XML::Compile::Transport::SOAPHTTP;
 use File::ShareDir ();
 
+has server_version => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'Exchange2007_SP1',
+    required => 0,
+);
+
+has use_negotiated_auth => (
+    is => 'ro',
+    isa => 'Any',
+    default => 0,
+    required => 0,
+);
+
 has transporter => (
     is => 'ro',
     isa => 'XML::Compile::Transport::SOAPHTTP',
@@ -14,9 +31,22 @@ has transporter => (
 
 sub _build_transporter {
     my $self = shift;
-    return XML::Compile::Transport::SOAPHTTP->new( address =>
-        sprintf 'https://%s:%s@%s/EWS/Exchange.asmx',
-            $self->username, $self->password, $self->server );
+    my $addr = $self->server . '/EWS/Exchange.asmx';
+
+    if (not $self->use_negotiated_auth) {
+        $addr = sprintf '%s:%s@%s',
+            $self->username, $self->password, $addr;
+    }
+
+    my $t = XML::Compile::Transport::SOAPHTTP->new(
+        address => 'https://'. $addr);
+    
+    if ($self->use_negotiated_auth) {
+        $t->userAgent->credentials($self->server.':443', '',
+            $self->username, $self->password);
+    }
+
+    return $t;
 }
 
 has wsdl => (
